package com.tiptimes.service.impl;


import com.tiptimes.dao.QuestionnaireDao;
import com.tiptimes.model.Answer;
import com.tiptimes.model.Record;
import com.tiptimes.model.Review;
import com.tiptimes.service.QuestionnaireService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;


@Service
public class QuestionnaireServiceImpl implements QuestionnaireService {
    @Autowired
    private QuestionnaireDao questionnaireDao;

    /**
     * 根据上报人和问卷id查询上报记录id
     * @param questionnaireUuid 问卷id
     * @param createId 上报人唯一标识
     * @return
     */
    @Override
    @Transactional(readOnly = true)
    public Long selectRecordId(Long questionnaireUuid, String createId) {
        return questionnaireDao.selectRecordId(questionnaireUuid,createId);
    }

    /**
     * 添加上报记录
     * @param record 上报记录
     * @return
     */
    @Override
    @Transactional
    public Long insertRecord(Record record) {
        return questionnaireDao.insertRecord(record);
    }

    /**
     * 根据上报记录id删除原上报数据
     * @param recordId 上报记录id
     * @return
     */
    @Override
    @Transactional
    public Integer delAnswer(Long recordId) {
        return questionnaireDao.delAnswer(recordId);
    }

    /**
     * 添加上报数据
     * @param answerList
     * @param recordId
     * @return
     */
    @Override
    @Transactional
    public Integer insertAnswer(List<Answer> answerList, Long recordId) {
        return questionnaireDao.insertAnswer(answerList,recordId);
    }

    /**
     * 修改上报记录
     * @param record
     * @return
     */
    @Override
    @Transactional
    public Integer updateRecord(Record record) {
        return questionnaireDao.updateRecord(record);
    }

    /**
     * 通过记录id删除原有备注
     * @param recordId
     * @return
     */
    @Override
    @Transactional
    public Integer delView(Long recordId) {
        return questionnaireDao.delView(recordId);
    }

    /**
     * 添加新的备注
     * @param review
     * @return
     */
    @Override
    @Transactional
    public Integer insertReview(List<Review> review,Long recordId) {
        return questionnaireDao.insertReview(review,recordId);
    }

    /**
     * 通过记录id删除原有备注
     * @param recordId
     * @return
     */
    @Override
    public List<Answer> selectAnswerByRecordId(Long recordId) {
        return questionnaireDao.selectAnswerByRecordId(recordId);
    }

    /**
     * 根据记录id查询评审备注详情
     * @param recordId 记录id
     * @return
     */
    @Override
    public List<Review> selectReviewByRecordId(Long recordId) {
        return questionnaireDao.selectReviewByRecordId(recordId);
    }

    @Override
    public Record selectById(Long recordId) {
        return questionnaireDao.selectById(recordId);
    }

    /**
     * 按条件查询上报记录
     * @param record 筛选条件
     * @return
     */
    @Override
    public List<Record> selectRecordList(Record record) {
        return questionnaireDao.selectRecordList(record);
    }
}
